@@ -1,10 +1,10 @@
-mod statsf64;
-mod statsi64;
-mod vecf64;
-mod vecu8;
-mod vecvecu8;
-mod mutvec;
-mod vecvecf64;
+pub mod statsf64;
+pub mod statsi64;
+pub mod vecf64;
+pub mod vecu8;
+pub mod vecvecu8;
+pub mod mutvec;
+pub mod vecvecf64;
 pub mod functions;
 
 /// simple error handling
@@ -123,12 +123,14 @@ pub trait Stats {
     /// Median and quartiles
     fn median(self) -> Result<Med>
         where Self: std::marker::Sized { bail!("median not implemented for this type")}
+/*        
     /// Creates vector of ranks for values in self
     fn ranks(self) -> Result<Vec<f64>>
         where Self: std::marker::Sized { bail!("ranks not implemented for this type")}
     /// Creates vector of integer ranks for values in self
     fn iranks(self) -> Result<Vec<i64>>
         where Self: std::marker::Sized { bail!("iranks not implemented for this type")}    
+*/
 }
 
 /// Vector algebra on one or two vectors.
@@ -184,12 +186,12 @@ pub trait Vecf64 {
     /// Reconstructs the full symmetric matrix from its lower diagonal compact form
     fn symmatrix(self) -> Vec<Vec<f64>>;
  
-    /// Minimum, minimum's index, maximum, maximum's index.
-    fn minmax(self) -> (f64, usize, f64, usize); 
+    // Minimum, minimum's index, maximum, maximum's index.
+    // fn minmax(self) -> (f64, usize, f64, usize); 
     /// Linear transformation to [0,1]
     fn lintrans(self) -> Vec<f64>;
-    /// Sort vector in a standard way
-    fn sortf(self) -> Vec<f64>; 
+    // Sort vector in a standard way
+    // fn sortf(self) -> Vec<f64>; 
 }
 
 /// Some support for Vec<u8> (vector of bytes)
@@ -268,7 +270,6 @@ pub trait MutVectors {
     fn mutvunit(self) where Self: std::marker::Sized {}
     /// sort in place
     fn mutsortf(self) where Self: std::marker::Sized {} 
-
 }
 
 /// Some support for self argument of Vec<Vec<u8>> type (vector of vectors of bytes)
